@@ -5,6 +5,7 @@ RSpec.describe JWT do
 
   let :data do
    data = {
+      :empty_token => 'e30K.e30K.e30K',
       :secret => 'My$ecretK3y',
       :rsa_private => OpenSSL::PKey.read(File.read(File.join(CERT_PATH, 'rsa-2048-private.pem'))),
       :rsa_public => OpenSSL::PKey.read(File.read(File.join(CERT_PATH, 'rsa-2048-public.pem'))),
@@ -33,9 +34,13 @@ RSpec.describe JWT do
     }
 
     if defined?(RbNaCl)
+      ed25519_private = RbNaCl::Signatures::Ed25519::SigningKey.new('abcdefghijklmnopqrstuvwxyzABCDEF')
+      ed25519_public =  ed25519_private.verify_key
       data.merge!(
-        'ED25519_private' =>  RbNaCl::Signatures::Ed25519::SigningKey.new('abcdefghijklmnopqrstuvwxyzABCDEF'),
-        'ED25519_public' => RbNaCl::Signatures::Ed25519::SigningKey.new('abcdefghijklmnopqrstuvwxyzABCDEF').verify_key,
+        'ED25519_private' =>  ed25519_private,
+        'ED25519_public' => ed25519_public,
+        'EdDSA_private' =>  ed25519_private,
+        'EdDSA_public' => ed25519_public,
       )
     end
     data
@@ -187,7 +192,7 @@ RSpec.describe JWT do
   end
 
   if defined?(RbNaCl)
-    %w[ED25519].each do |alg|
+    %w[ED25519 EdDSA].each do |alg|
       context "alg: #{alg}" do
         before(:each) do
           data[alg] = JWT.encode payload, data["#{alg}_private"], alg
@@ -411,6 +416,14 @@ RSpec.describe JWT do
           expect(jwt_payload).to eq payload
         end
       end
+
+      context 'token is missing algorithm' do
+        it 'should raise JWT::IncorrectAlgorithm' do
+          expect do
+            JWT.decode data[:empty_token]
+          end.to raise_error JWT::IncorrectAlgorithm
+        end
+      end
     end
 
     context 'issuer claim' do
@@ -528,4 +541,34 @@ RSpec.describe JWT do
       end.to raise_error(NotImplementedError)
     end
   end
+
+  describe '::JWT.decode with verify_iat parameter' do
+    let!(:time_now) { Time.now }
+    let(:token)     { ::JWT.encode({ pay: 'load', iat: iat}, 'secret', 'HS256') }
+
+    subject(:decoded_token) { ::JWT.decode(token, 'secret', true, verify_iat: true) }
+
+    before { allow(Time).to receive(:now) { time_now } }
+
+    context 'when iat is exactly the same as Time.now and iat is given as a float' do
+      let(:iat) { time_now.to_f }
+      it 'considers iat valid' do
+        expect(decoded_token).to be_an(Array)
+      end
+    end
+
+    context 'when iat is exactly the same as Time.now and iat is given as floored integer' do
+      let(:iat) { time_now.to_f.floor }
+      it 'considers iat valid' do
+        expect(decoded_token).to be_an(Array)
+      end
+    end
+
+    context 'when iat is 1 second before Time.now' do
+      let(:iat) { time_now.to_i + 1 }
+      it 'raises an error' do
+        expect { decoded_token }.to raise_error(::JWT::InvalidIatError, 'Invalid iat')
+      end
+    end
+  end
 end
